@@ -30,7 +30,7 @@
 #include "settings.h"
 #include "programcatalog.h"
 #include "program.h"
-#include "actionregistry.h"
+#include <actionregistry.h>
 #include "actionrunprogram.h"
 
 K_EXPORT_COMPONENT_FACTORY( katapult_programcatalog,
